@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__spa__device.html#gab7ccc98f93f0269396bcbcd3efd1fdb8":[10,8,4,18],
+"group__spa__device.html#gabcb2230b6ab2020ceef73fad9e1fd7dc":[10,8,4,70],
 "group__spa__device.html#gac59665317b0bc49197df89771abf6499":[10,8,4,66],
 "group__spa__device.html#gac5d87bd2bc51abe0c370198371428f6f":[10,8,4,78],
 "group__spa__device.html#gac7701f46169fcc7a70be0f7167b97cff":[10,8,4,76],
@@ -247,7 +249,5 @@ var NAVTREEINDEX9 =
 "group__spa__log.html#ga0f6523b51087c252b5ccf1b68bdce51d":[10,8,9,3,42],
 "group__spa__log.html#ga142802024be8a40bef345806d498d6b6":[10,8,9,3,25],
 "group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14":[10,8,9,3,35],
-"group__spa__log.html#ga24e95908846b410227578abfc63b0bf0":[10,8,9,3,30],
-"group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1":[10,8,9,3,43],
-"group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8":[10,8,9,3,31]
+"group__spa__log.html#ga24e95908846b410227578abfc63b0bf0":[10,8,9,3,30]
 };
